import setuptools

setuptools.setup(
    name="lzttest",
    version="1.0.0",
    author="your_nickname",
    description="Something",
    url="https://github.com/Infqq/simpledemotivators",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
)
